==> apache-superset-1.5.3-source.tar.gz: apache-superset-1.5.3rc1/docs/src/resources/data.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export const Databases = [
  {
    title: 'Amazon Redshfit',
    href: 'https://aws.amazon.com/redshift/',
    imgName: 'aws-redshift.png',
  },
  {
    title: 'Apache Druid',
    href: 'http://druid.io/',
    imgName: 'druid.png',
  },
  {
    title: 'Apache Kylin',
    href: 'http://kylin.apache.org/',
    imgName: 'apache-kylin.png',
  },
  {
    title: 'BigQuery',
    href: 'https://cloud.google.com/bigquery/',
    imgName: 'googleBQ.png',
  },
  {
    title: 'ClickHouse',
    href: 'https://clickhouse.tech/',
    imgName: 'clickhouse.png',
  },
  {
    title: 'Dremio',
    href: 'https://dremio.com/',
    imgName: 'dremio.png',
  },
  {
    title: 'Exasol',
    href: 'https://www.exasol.com/en/',
    imgName: 'exasol.png',
  },
  {
    title: 'FireBirdSql',
    href: 'https://firebirdsql.org/',
    imgName: 'firebird.png',
  },
  {
    title: 'Green Plum',
    href: 'https://greenplum.org/',
    imgName: 'greenplum.png',
  },
  {
    title: 'IBM Db2',
    href: 'https://www.ibm.com/analytics/db2',
    imgName: 'ibmdb2.png',
  },
  {
    title: 'MySQL',
    href: 'https://www.mysql.com/',
    imgName: 'mysql.png',
  },
  {
    title: 'Microsoft SqlServer',
    href: 'https://www.microsoft.com/en-us/sql-server',
    imgName: 'msql.png',
  },
  {
    title: 'MonetDB',
    href: 'https://www.monetdb.org/',
    imgName: 'monet.png',
  },
  {
    title: 'Oracle',
    href: 'https://www.oracle.com/database/',
    imgName: 'oraclelogo.png',
  },
  {
    title: 'PostgresSQL',
    href: 'https://www.postgresql.org/',
    imgName: 'postsql.png',
  },
  {
    title: 'Presto',
    href: 'https://prestodb.io/',
    imgName: 'presto-og.png',
  },
  {
    title: 'Snowflake',
    href: 'https://www.snowflake.com/',
    imgName: 'snowflake.png',
  },
  {
    title: 'SQLite',
    href: 'https://www.sqlite.org/index.html',
    imgName: 'sqllite.png',
  },
  {
    title: 'Trino',
    href: 'https://trino.io/',
    imgName: 'trino2.jpg',
  },
  {
    title: 'Rockset',
    href: 'https://rockset.com/',
    imgName: 'rockset.png',
  },
  {
    title: 'Vertica',
    href: 'https://www.vertica.com/',
    imgName: 'vertica.png',
  },
  {
    title: 'Hologres',
    href: 'https://www.alibabacloud.com/product/hologres',
    imgName: 'hologres.png',
  },
  {
    title: 'IBM Netezza Performance Server',
    href: 'https://www.ibm.com/products/netezza',
    imgName: 'netezza.png',
  },
  {
    title: 'Teradata',
    href: "www.teradata.com",
    imgName: 'teradata.png'
  },
  {
    title: 'YugabyteDB',
    href: "www.yugabyte.com",
    imgName: 'yugabyte.png'
  }
];

==> apache-superset-2.0.1rc3-source.tar.gz: apache-superset-2.0.1rc3/docs/src/resources/data.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export const Databases = [
  {
    title: 'Amazon Redshift',
    href: 'https://aws.amazon.com/redshift/',
    imgName: 'aws-redshift.png',
  },
  {
    title: 'Apache Druid',
    href: 'http://druid.io/',
    imgName: 'druid.png',
  },
  {
    title: 'Apache Kylin',
    href: 'http://kylin.apache.org/',
    imgName: 'apache-kylin.png',
  },
  {
    title: 'BigQuery',
    href: 'https://cloud.google.com/bigquery/',
    imgName: 'googleBQ.png',
  },
  {
    title: 'ClickHouse',
    href: 'https://clickhouse.tech/',
    imgName: 'clickhouse.png',
  },
  {
    title: 'Dremio',
    href: 'https://dremio.com/',
    imgName: 'dremio.png',
  },
  {
    title: 'Exasol',
    href: 'https://www.exasol.com/en/',
    imgName: 'exasol.png',
  },
  {
    title: 'FireBirdSql',
    href: 'https://firebirdsql.org/',
    imgName: 'firebird.png',
  },
  {
    title: 'Green Plum',
    href: 'https://greenplum.org/',
    imgName: 'greenplum.png',
  },
  {
    title: 'IBM Db2',
    href: 'https://www.ibm.com/analytics/db2',
    imgName: 'ibmdb2.png',
  },
  {
    title: 'MySQL',
    href: 'https://www.mysql.com/',
    imgName: 'mysql.png',
  },
  {
    title: 'Microsoft SqlServer',
    href: 'https://www.microsoft.com/en-us/sql-server',
    imgName: 'msql.png',
  },
  {
    title: 'MonetDB',
    href: 'https://www.monetdb.org/',
    imgName: 'monet.png',
  },
  {
    title: 'Oracle',
    href: 'https://www.oracle.com/database/',
    imgName: 'oraclelogo.png',
  },
  {
    title: 'PostgresSQL',
    href: 'https://www.postgresql.org/',
    imgName: 'postsql.png',
  },
  {
    title: 'Presto',
    href: 'https://prestodb.io/',
    imgName: 'presto-og.png',
  },
  {
    title: 'Snowflake',
    href: 'https://www.snowflake.com/',
    imgName: 'snowflake.png',
  },
  {
    title: 'SQLite',
    href: 'https://www.sqlite.org/index.html',
    imgName: 'sqlite.png',
  },
  {
    title: 'Trino',
    href: 'https://trino.io/',
    imgName: 'trino2.jpg',
  },
  {
    title: 'Rockset',
    href: 'https://rockset.com/',
    imgName: 'rockset.png',
  },
  {
    title: 'Vertica',
    href: 'https://www.vertica.com/',
    imgName: 'vertica.png',
  },
  {
    title: 'Hologres',
    href: 'https://www.alibabacloud.com/product/hologres',
    imgName: 'hologres.png',
  },
  {
    title: 'IBM Netezza Performance Server',
    href: 'https://www.ibm.com/products/netezza',
    imgName: 'netezza.png',
  },
  {
    title: 'Teradata',
    href: "www.teradata.com",
    imgName: 'teradata.png'
  },
  {
    title: 'YugabyteDB',
    href: "www.yugabyte.com",
    imgName: 'yugabyte.png'
  }
];
